Hi,

On Tue, Sep 9, 2014 at 6:18 PM, Chris Zhong <z...@rock-chips.com> wrote:
> Signed-off-by: Chris Zhong <z...@rock-chips.com>
>
> Tested-by: Heiko Stuebner <he...@sntech.de>
> ---
>
> Changes in v10: None

Despite the "None" above, I see that there are indeed changes between
v9 and v10:

diff --git a/drivers/regulator/rk808-regulator.c
b/drivers/regulator/rk808-regulator.c
index 0d5afc4..d91f2b6 100644
--- a/drivers/regulator/rk808-regulator.c
+++ b/drivers/regulator/rk808-regulator.c
@@ -3,8 +3,8 @@
  *
  * Copyright (c) 2014, Fuzhou Rockchip Electronics Co., Ltd
  *
  * Author: Chris Zhong<z...@rock-chips.com>
  * Author: Zhang Qing<zhanqg...@rock-chips.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms and conditions of the GNU General Public License,
@@ -348,6 +348,6 @@ module_platform_driver(rk808_regulator_driver);

 MODULE_DESCRIPTION("regulator driver for the rk808 series PMICs");
 MODULE_AUTHOR("Chris Zhong<z...@rock-chips.com>");
-MODULE_AUTHOR("Zhang Qing<zhanqg...@rock-chips.com>");
+MODULE_AUTHOR("Zhang Qing<zhangq...@rock-chips.com>");
 MODULE_LICENSE("GPL");
 MODULE_ALIAS("platform:rk808-regulator");

That looks like the change requested by Dmitry for v9 (don't remove
the space) plus a typo fix (flipping g/q).  Interestingly enough the
typo fix shows that "MODULE_AUTHOR" should probably also have had a
space before the "<".


Mark: I think you could just take this (possibly fixing the
MODULE_AUTHOR yourself) to fix the linux-next breakage.  You can also
add:

Reviewed-by: Doug Anderson <diand...@chromium.org>
Tested-by: Doug Anderson <diand...@chromium.org>

-Doug
@@ -3,8 +3,8 @@
  * Copyright (c) 2014, Fuzhou Rockchip Electronics Co., Ltd
  *
- * Author: Chris Zhong<z...@rock-chips.com>
- * Author: Zhang Qing<zhanqg...@rock-chips.com>
+ * Author: Chris Zhong <z...@rock-chips.com>
+ * Author: Zhang Qing <zhangq...@rock-chips.com>
  *
  * This program is free software; you can redistribute it and/or modify it
--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to